<?php

namespace FiloBlu\GuestWishlist\Cron;

class CleanOldGuestWishlist {

    protected $_helper;
    protected $_loggerCron;
    protected $_wishlistCollectionFactory;

    public function __construct(
        \FiloBlu\GuestWishlist\Helper\Data $helper,
        \FiloBlu\GuestWishlist\Model\Logger\LoggerCron $loggerCron,
        \Magento\Wishlist\Model\ResourceModel\Wishlist\CollectionFactory $wishlistCollectionFactory
    ) {
        $this->_helper = $helper;
        $this->_loggerCron = $loggerCron;
        $this->_wishlistCollectionFactory = $wishlistCollectionFactory;
    }

    public function execute() {

        if ($this->_helper->isCronEnabled()) {
            try {

                $this->_loggerCron->info(" #### START CRON CleanOldWishlist #### ");

                // Current date and time
                $datetime = date("Y-m-d H:i:s");


                // Convert datetime to Unix timestamp
                $timestamp = strtotime($datetime);


                // Subtract time from datetime
                $time = $timestamp - ($this->_helper->getCookielifetime());


                // Date and time after subtraction
                $datetime = date("Y-m-d H:i:s", $time);

                $collection = $this->_wishlistCollectionFactory->create();
                $collection->addFieldToFilter('customer_id', array('null' => true));
                $collection->addFieldToFilter('updated_at', ['lteq' => $datetime]);


                foreach ($collection as $item) {
                    $item->delete();
                }

                $this->_loggerCron->info(" #### Clean Wishlist Before -> " . $datetime . " #### ");

                $this->_loggerCron->info(" #### Clean Wishlist Count COUNT -> " . count($collection) . " #### ");

                
                $this->_loggerCron->info(" #### END CRON CleanOldWishlist #### ");
                
            } catch (\Exception $e) {
                $this->_loggerCron->info(" #### ERROR -> " . $e->getMessage() . " #### ");
            }
        }
    }

}
